package
Version:
v0.0.0-...-d4686d0
Opens a new window with list of versions in this module.
Published: Feb 20, 2021
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
-
func Distinct(a []uint8) (r []uint8)
-
func GCD(a ...uint8) uint8
-
func GCD2(m, n uint8) uint8
-
func Insert(a []uint8, index int, value uint8) []uint8
-
func IsValue(buffer []uint8, value uint8) bool
-
func IsZero(buffer []uint8) bool
-
func Max(a ...uint8) uint8
-
func Max2(a, b uint8) uint8
-
func Memset(a []uint8, value uint8)
-
func Min(a ...uint8) uint8
-
func Min2(a, b uint8) uint8
-
func MinMax(a ...uint8) (uint8, uint8)
-
func MinMax2(a, b uint8) (uint8, uint8)
-
func Mul(a ...uint8) uint8
-
func Remove(a []uint8, index int) []uint8
-
func Reverse(a []uint8)
-
func Sum(a ...uint8) uint8
-
func Thousands(rs []uint8) string
-
func ToHex(buf []byte, countPerLine int) string
Distinct returns a new slice with all duplicate values removed.
GCD returns greatest common divisor
GCD2 returns greatest common divisor
Insert the value at the index of the slice
0 <= index <= len(a)
IsValue returns ture if buffer filled with the value, otherwise false.
IsZero returns ture for all zero buffer, otherwise false.
Max returns a maximum of all input arguments
Max2 returns a if a >= b else b
Memset fills the slice with the value.
Min returns a minimum of all input arguments
Min2 returns a if a <= b else b
MinMax returns a (minimum, maximum) of all input arguments
MinMax2 returns a (minimum, maximum) of input arguments
Mul returns mul of all input values
Remove the value at the index.
Reverse the slice in place.
Sum returns sum of all input values
Thousands returns thousands separated by underline e.g.: 1_234_567
ToHex returns countPerLine Hex string of buf content.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.